@@ -1,5 +1,5 @@
 /* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2006 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2006 - 2008 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -66,7 +66,8 @@
 /* Ignore dot at the end of the word (needed for use in some word processors).
  * If this option is set and input word ends with a dot, spell checking and
  * hyphenation functions try to analyse the word without the dot if no results
- * can be obtained for the original form.
+ * can be obtained for the original form. Also with this option, string tokenizer
+ * will consider trailing dot of a word to be a part of that word.
  * Default: false */
 #define VOIKKO_OPT_IGNORE_DOT 0
 
@@ -117,6 +118,13 @@
  * Default: false */
 #define VOIKKO_OPT_ACCEPT_MISSING_HYPHENS 12
 
+/* (Grammar checking only): Accept incomplete sentences that could occur in
+ * titles or headings. Set this option to true if your application is not able
+ * to differentiate titles from normal text paragraphs, or if you know that
+ * you are checking title text.
+ * Default: false */
+#define VOIKKO_OPT_ACCEPT_TITLES_IN_GC 13
+
 /* Integer options */
 
 /* There are two possible rules that can be applied when hyphenating compound words
@@ -135,9 +143,28 @@
 /* String options */
 /* The encoding in which multibyte character strings are interpreteted and returned
  * as results.
+ * This option is deprecated. Future releases will support UTF-8 encoding only.
  * Default: UTF-8 */
 #define VOIKKO_OPT_ENCODING 2
 
+/**
+ * Grammar error description.
+ */
+typedef struct {
+	/** Error code. 0 = no error was found */
+	int error_code;
+	/** Unused (indicates the probability of a false positive) */
+	int error_level;
+	/** Unused (detailed error description) */
+	char * error_description;
+	/** Start position of the error in the text */
+	size_t startpos;
+	/** Length of the error in the text */
+	size_t errorlen;
+	/** Possible corrections. These should be freed after
+	 *  use by calling voikko_free_suggest_cstr */
+	char ** suggestions;
+} voikko_grammar_error;
 
 #ifndef VOIKKO_DEFS_H
 BEGIN_C_DECLS
@@ -163,7 +190,7 @@ const char * voikko_init(int * handle, const char * langcode, int cache_size);
  * @param cache_size size of the spellchecker cache. This can be -1 (no cache) or
  *        >= 0 ( size in bytes = 2^cache_size * (6544*sizeof(wchar_t) + 1008) ).
  * @param path path to a directory from which dictionary files should be searched
- *        first before looking into the standard dictionary locatiosn
+ *        first before looking into the standard dictionary locations
  * @return null, if initialisation completed without error, otherwise a pointer
  *         to a string describing the error
  */
@@ -312,6 +339,61 @@ enum voikko_token_type voikko_next_token_ucs4(int handle, const wchar_t * text,
 enum voikko_token_type voikko_next_token_cstr(int handle, const char * text, size_t textlen,
                                               size_t * tokenlen);
 
+/**
+ * Sentence start types
+ * SENTENCE_NONE: End of text reached or error.
+ * SENTENCE_NO_START: This is not a start of a new sentence.
+ * SENTENCE_POSSIBLE: This may be a start of a new sentence.
+ * SENTENCE_PROBABLE: This is a probable start of a new sentence.
+ */
+enum voikko_sentence_type {SENTENCE_NONE, SENTENCE_NO_START, SENTENCE_PROBABLE, SENTENCE_POSSIBLE};
+
+/**
+ * Find the next sentence in text stream.
+ * @param handle voikko instance
+ * @param text Pointer to the start of a text buffer
+ * @param textlen Number of characters left in the buffer
+ * @param sentencelen (out) Offset of the character that starts the next sentence.
+ * @return Type of the next found sentence, if any.
+ */
+enum voikko_sentence_type voikko_next_sentence_start_ucs4(int handle, const wchar_t * text,
+     size_t textlen, size_t * sentencelen);
+
+/**
+ * Find the next sentence in text stream.
+ * @param handle voikko instance
+ * @param text Pointer to the start of a text buffer
+ * @param textlen Number of bytes left in the buffer
+ * @param sentencelen (out) Offset of the character (in charactes, not bytes) that
+ *        starts the next sentence.
+ * @return Type of the next found sentence, if any.
+ */
+enum voikko_sentence_type voikko_next_sentence_start_cstr(int handle, const char * text,
+     size_t textlen, size_t * sentencelen);
+
+/**
+ * Find next grammar error.
+ * @param handle Voikko instance
+ * @param text Pointer to the start of a text buffer. This should usually
+ *        be at the start of a paragraph or a sentence.
+ * @param textlen Number of bytes in the buffer. The end of the buffer should
+ *        be the end of a paragraph or a sentence.
+ * @param startpos Do not consider errors that start before this character
+ *        offset from the start of the text.
+ * @param skiperrors Skip this number of errors from the start of the text.
+ * @return Grammar error description.
+ */
+voikko_grammar_error voikko_next_grammar_error_cstr(int handle, const char * text,
+                     size_t textlen, size_t startpos, int skiperrors);
+
+/**
+ * Localized error message.
+ * @param error_code Error code (from voikko_grammar_error)
+ * @param language ISO language code or null, if the language from current locale
+ *        should be used.
+ * @return The UTF-8 encoded localized error message for the error code.
+ */
+const char * voikko_error_message_cstr(int error_code, const char * language);
 
 END_C_DECLS
 #endif
