@@ -1,5 +1,5 @@
 /* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2006 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2006 - 2008 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -69,11 +69,27 @@ VOIKKOEXPORT void voikko_free_suggest_cstr(char ** suggest_result);
 
 VOIKKOEXPORT void voikko_free_hyphenate(char * hyphenate_result);
 
-VOIKKOEXPORT enum voikko_token_type {TOKEN_NONE, TOKEN_WORD, TOKEN_PUNCTUATION, TOKEN_WHITESPACE, TOKEN_UNKNOWN};
+VOIKKOEXPORT enum voikko_token_type {TOKEN_NONE, TOKEN_WORD, TOKEN_PUNCTUATION,
+             TOKEN_WHITESPACE, TOKEN_UNKNOWN};
 
 VOIKKOEXPORT enum voikko_token_type voikko_next_token_ucs4(int handle, const wchar_t * text,
                                                            size_t textlen, size_t * tokenlen);
 
 VOIKKOEXPORT enum voikko_token_type voikko_next_token_cstr(int handle, const char * text, size_t textlen,
                                                            size_t * tokenlen);
+
+VOIKKOEXPORT enum voikko_sentence_type {SENTENCE_NONE, SENTENCE_NO_START,
+             SENTENCE_PROBABLE, SENTENCE_POSSIBLE};
+
+VOIKKOEXPORT enum voikko_sentence_type voikko_next_sentence_start_ucs4(int handle,
+             const wchar_t * text, size_t textlen, size_t * sentencelen);
+
+VOIKKOEXPORT enum voikko_sentence_type voikko_next_sentence_start_cstr(int handle,
+             const char * text, size_t textlen, size_t * sentencelen);
+
+VOIKKOEXPORT voikko_grammar_error voikko_next_grammar_error_cstr(int handle, const char * text,
+                                  size_t textlen, size_t startpos, int skiperrors);
+
+VOIKKOEXPORT const char * voikko_error_message_cstr(int error_code, const char * language);
+
 #endif
