@@ -77,6 +77,10 @@ int voikko_set_bool_option(int handle, int option, int value) {
 			if (value) voikko_options.accept_missing_hyphens = 1;
 			else voikko_options.accept_missing_hyphens = 0;
 			return 1;
+		case VOIKKO_OPT_ACCEPT_TITLES_IN_GC:
+			if (value) voikko_options.accept_titles_in_gc = 1;
+			else voikko_options.accept_titles_in_gc = 0;
+			return 1;
 	}
 	return 0;
 }
@@ -134,11 +138,13 @@ const char * voikko_init_with_path(int * handle, const char * langcode,
 	voikko_options.no_ugly_hyphenation = 0;
 	voikko_options.accept_extra_hyphens = 0;
 	voikko_options.accept_missing_hyphens = 0;
+	voikko_options.accept_titles_in_gc = 0;
 	voikko_options.intersect_compound_level = 1;
 	voikko_options.min_hyphenated_word_length = 2;
 	voikko_options.encoding = "UTF-8";
 	voikko_options.cache_size = cache_size;
 	voikko_options.suggestion_type = ST_STD;
+	init_gc_cache(&voikko_options.gc_cache);
 	
 	project = malloc(1024);
 	if (project == 0) return "Out of memory";
@@ -227,6 +233,7 @@ int voikko_terminate(int handle) {
 			free(voikko_options.cache);
 			free(voikko_options.cache_meta);
 		}
+		gc_clear_cache(handle);
 		return 1;
 	}
 	else return 0;
