@@ -19,6 +19,7 @@
 #ifndef VOIKKO_SETUP_H
 #define VOIKKO_SETUP_H
 
+#include "gccache.h"
 #ifdef HAVE_ICONV
   #include <iconv.h>
 #endif
@@ -39,6 +40,7 @@ typedef struct {
 	int accept_missing_hyphens;
 	int intersect_compound_level;
 	int min_hyphenated_word_length;
+	int accept_titles_in_gc;
 	const char * encoding;
 	#ifdef HAVE_ICONV
 	iconv_t iconv_ucs4_utf8;
@@ -50,6 +52,7 @@ typedef struct {
 	char * cache_meta;
 	int cache_size;
 	enum suggtype suggestion_type;
+	voikko_gc_cache gc_cache;
 } voikko_options_t;
 
 extern voikko_options_t voikko_options;
